<?php
/**
 * Plugin Name:  MediaPress Vimeo Integration
 * Version:      1.0.0
 * Plugin URI:   https://buddydev.com/plugins/mpp-vimeo-integration
 * Description:  This plugin is an addon for MediaPress which allow user to host video through vimeo.
 * Author:       BuddyDev
 * Author URI:   https://buddydev.com/
 * Requires PHP: 7.1
 * License:      GPL2
 * License URI:  https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:  mpp-vimeo-integration
 * Domain Path:  /languages
 *
 * @package mpp-vimeo-integration
 **/

use MPP_Vimeo_Integration\Bootstrap\Autoloader;
use MPP_Vimeo_Integration\Bootstrap\MPP_VIMEO_Bootstrapper;

// No direct access over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class MPP_Vimeo_Integration
 *
 * @property-read $path        string Absolute path to the plugin directory.
 * @property-read $url         string Absolute url to the plugin directory.
 * @property-read $basename    string Plugin base name.
 * @property-read $version     string Plugin version.
 * @property-read $php_version string Minimum php version.
 */
class MPP_Vimeo_Integration {

	/**
	 * Plugin Version.
	 *
	 * @var string
	 */
	private $version = '1.0.0';

	/**
	 * Minimum php version
	 *
	 * @var string
	 */
	private $php_version = '7.1';

	/**
	 * Class instance
	 *
	 * @var MPP_Vimeo_Integration
	 */
	private static $instance = null;

	/**
	 * Plugin absolute directory path
	 *
	 * @var string
	 */
	private $path;

	/**
	 * Plugin absolute directory url
	 *
	 * @var string
	 */
	private $url;

	/**
	 * Plugin Basename.
	 *
	 * @var string
	 */
	private $basename;

	/**
	 * Protected properties. These properties are inaccessible via magic method.
	 *
	 * @var array
	 */
	private $guarded_properties = array( 'instance' );

	/**
	 * MPP_Vimeo_Integration constructor.
	 */
	private function __construct() {
		$this->bootstrap();
		$this->setup();
	}

	/**
	 * Get Singleton Instance
	 *
	 * @return MPP_Vimeo_Integration
	 */
	public static function get_instance() {

		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Bootstrap the core.
	 */
	private function bootstrap() {
		$this->path     = plugin_dir_path( __FILE__ );
		$this->url      = plugin_dir_url( __FILE__ );
		$this->basename = plugin_basename( __FILE__ );

		// Load autoloader.
		require_once $this->path . 'src/bootstrap/class-autoloader.php';

		$autoloader = new Autoloader( 'MPP_Vimeo_Integration\\', __DIR__ . '/src/' );

		try {
			spl_autoload_register( $autoloader );
		} catch ( Exception $e ) {
			wp_die( esc_html( __( 'Vimeo integration autoloader not loaded', 'mpp-vimeo-integration' ) ) );
		}

		// Load vimeo api autoloader.
		require_once $this->path . 'vendors/vimeo/vimeo-api/autoload.php';
	}

	/**
	 * Setup class
	 */
	public function setup() {
		register_activation_hook( __FILE__, array( $this, 'on_activation' ) );
		MPP_VIMEO_Bootstrapper::boot();
	}

	/**
	 * On activation
	 */
	public function on_activation() {
		if ( ! wp_next_scheduled( 'my_hourly_event' ) ) {
			wp_schedule_event( time(), 'hourly', 'pp_vimeo_hourly_check' );
		}
	}

	/**
	 * Magic method for accessing property as readonly(It's a lie, references can be updated).
	 *
	 * @param string $name property name.
	 *
	 * @return mixed|null
	 */
	public function __get( $name ) {

		if ( property_exists( $this, $name ) && ! in_array( $name, $this->guarded_properties, true ) ) {
			return $this->{$name};
		}

		return null;
	}
}

/**
 * Helper to access singleton instance
 *
 * @return MPP_Vimeo_Integration
 */
function mpp_vimeo() {
	return MPP_Vimeo_Integration::get_instance();
}

mpp_vimeo();
