<?php
/**
 * Admin Settings Pages Helper.
 *
 * @package    MPP_Vimeo_Integration
 * @subpackage Admin
 * @copyright  Copyright (c) 2018, BuddyDev.Com
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Ravi Sharma, Brajesh Singh
 * @since      1.0.0
 */

namespace MPP_Vimeo_Integration\Admin;

use MPP_Vimeo_Integration\Bootstrap\MPP_Vimeo_Bootable;

// Exit if file accessed directly over web.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Admin_Settings
 */
class MPP_Vimeo_Admin_Settings {

	use MPP_Vimeo_Bootable;

	/**
	 * Setup settings
	 */
	public function setup() {
		add_action( 'mpp_admin_register_settings', array( $this, 'register' ) );
	}

	/**
	 * Initialize the admin settings panel and fields
	 *
	 * @param \MPP_Admin_Settings_Page $page Page object.
	 */
	public function register( $page ) {
		$vpanel   = $page->add_panel( 'vimeo', _x( 'Vimeo', 'Admin settings panel title', 'mpp-vimeo-integration' ) );
		$vsection = $vpanel->add_section( 'api-settings', _x( 'Vimeo API Settings', 'Admin settings section title', 'mpp-vimeo-integration' ) );

		$fields = array(
			array(
				'name'    => 'mpp_vimeo_client_id',
				'label'   => _x( 'Client Id', 'Admin settings', 'mpp-vimeo-integration' ),
				'type'    => 'text',
				'default' => '',
			),
			array(
				'name'    => 'mpp_vimeo_client_secret',
				'label'   => _x( 'Client Secret', 'Admin settings', 'mpp-vimeo-integration' ),
				'type'    => 'text',
				'default' => '',
			),
			array(
				'name'    => 'mpp_vimeo_access_token',
				'label'   => _x( 'Access token', 'Admin settings', 'mpp-vimeo-integration' ),
				'type'    => 'text',
				'default' => '',
			),
		);

		$vsection->add_fields( $fields );
	}
}
