<?php
/**
 * Core functions file
 *
 * @package MPP_Vimeo_Integration
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get setting
 *
 * @param string $setting Setting name.
 *
 * @return mixed
 */
function wp_skeleton_get_option( $setting = '' ) {

	$settings = get_option( 'wp_skeleton_settings', wp_skeleton_get_default_options() );

	if ( isset( $settings[ $setting ] ) ) {
		return $settings[ $setting ];
	}

	return null;
}

/**
 * Get default options.
 *
 * @return array
 */
function wp_skeleton_get_default_options() {
	return array(
		'slug' => '',
	);
}

/**
 * Locate or load a file from theme or fallback to plugin.
 *
 * @param array $templates templates.
 * @param bool  $load load template?.
 *
 * @return string
 */
function wp_skeleton_locate_template( $templates, $load = false ) {
	$template_base = 'mpp-vimeo-integration/default';

	foreach ( $templates as $key => $template ) {
		$templates[ $key ] = $template_base . '/' . $template; // prefix the base.
	}

	$located = locate_template( $templates, false, false );

	if ( ! $located ) {
		$path = mpp_vimeo()->path . 'templates/';

		foreach ( $templates as $template ) {

			if ( ! is_readable( $path . $template ) ) {
				continue;
			}

			$located = $path . $template;
			break;
		}
	}

	if ( ! $load ) {
		return $located;
	}

	require $located;
}
